@@ -1,5 +1,5 @@
 # prime/prime-japnese.rb: Japanese module for PRIME.
-# $Id: prime-japanese.rb,v 1.3 2004/04/04 02:24:47 komatsu Exp $
+# $Id: prime-japanese.rb,v 1.6 2004/04/29 21:35:54 komatsu Exp $
 #
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -27,18 +27,19 @@ module PrimeJapanese
 	'Ը::Ϣi', 'Ը::Ϣi', 'ʹԸ::Ϣi', 
 	'йԸ::Ϣi', '޹Ը::Ϣi', 'Ը::Ϣi',
 	'Ը::Ϣi', '(Ԥ)::Ϣi',
-	'', 'ư::Ϣi'],
+	'', 'ư::Ϣi', '()'],
       'ư::' => ['Ը::', 'Ը::',
 	'Ը::', 'Ը::', 'ʹԸ::', 
 	'йԸ::', '޹Ը::', 'Ը::',
 	'Ը::', '(Ԥ)::',
-	'ư::', 'ư::', 'ư::'],
+	'ư::', 'ư::', 'ư::', '()'],
       'ư::' => ['֤::', 'Ǿá֤ʤ::'],
       'ư' => ['Ը', 'Ը', 'Ը', 'Ը', 'ʹԸ', 
 	'йԸ', '޹Ը', 'Ը', 'Ը', '(Ԥ)',
-	'', 'ư'],
+	'', 'ư', '()'],
       '' => ['ʽ֤ˡ', 'ʽ֤ǡ', 'ʽ֤',
-	'ʽ֤Ρ', 'ʽ֤', '֤ϡ'],
+                 'ʽ֤ȡ', 'ʽ֤Ρ', 'ʽ֤',
+                 '֤ϡ'],
       '̾' => ['̾', '()&̾', 'ư&̾'],
     }
 
@@ -75,7 +76,8 @@ module PrimeJapanese
       'ư::Ϣ' => ['̾', '̾&̾', '̾', '̾'],
       'ư' => ['̾', '̾&̾', '̾', '̾'],
       '֤::Ϣde' => ['ư'],
-      '' => ['̾', '̾&̾', '̾', '̾', 'ư'],
+      '' => ['̾', '̾&̾', '̾', '̾', 'ư', 'ƻ',
+                 'ư&̾'],
       'Ϣλ' => ['̾'],
     }
     @pos_connection_cost = {
@@ -223,6 +225,30 @@ module PrimeJapanese
     return results
   end
 
+  def search_japanese_uniclause (string)
+    string = PrimeTypeConv::convert(string).join
+
+    results = search_raw(string)
+    rest = nil
+
+    clauses_list = process_clauses(string)
+    clauses_list.each {|clauses|
+      if clauses.length == 1 then
+        ## FIXME: It's an adhoc routine.
+        ## FIXME: <komatsu@taiyaki.org> (2004-01-26)
+        (pron, pos, conjugation, conjugation_pos) = clauses.first
+        query = PrimeQuery.new([pron], pos)
+        words = search(query)
+        words.each {|word|
+          word.conjugation = conjugation
+        }
+        results += words
+      end
+    }
+
+    return results
+  end
+
   def get_pos_data (string)
     #| pos_data = {'pron1' => {'pos1-1' => [engine1-1-1, engine1-1-2, ...]
     #|                         'pos1-2' => [engine1-2-1, ...], ...},
