@@ -1,5 +1,5 @@
 # prime/prime.rb
-# $Id: prime.rb,v 1.11 2004/05/31 05:27:33 komatsu Exp $
+# $Id: prime.rb,v 1.12 2004/06/24 07:28:44 komatsu Exp $
 #
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -145,8 +145,7 @@ class Prime
         PRIME_ENV['typing_method'] == 'handwrite' then
       word_list = lookup_direct(string)
     else
-#      word_list = lookup_compact(string)
-      word_list = lookup_hybrid(string)
+      word_list = lookup_compact(string)
     end
     return word_list
   end
@@ -155,7 +154,7 @@ class Prime
         PRIME_ENV['typing_method'] == 'handwrite' then
       word_list = lookup_direct_all(string)
     else
-      word_list = lookup_hybrid_all(string)
+      word_list = lookup_compact_all(string)
     end
     return word_list
   end
