@@ -1,5 +1,5 @@
 # session.rb
-# $Id: session.rb,v 1.4 2004/03/25 17:19:49 komatsu Exp $
+# $Id: session.rb,v 1.5 2004/05/03 22:55:34 komatsu Exp $
 #
 # Copyright (C) 2001 Satoru Takabayashi <satoru@namazu.org>
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
@@ -56,19 +56,19 @@ class Session < SessionCore
   end
 
   def reply_successful (result = nil)
-    if result then
-      result += "\n"
-    else
+    if result.nil? or result.empty? then
       result = ""
+    else
+      result += "\n"
     end
     return ("ok\n" + result + "\n")
   end
 
   def reply_unsuccessful (result = nil)
-    if result then
-      result += "\n"
-    else
+    if result.nil? or result.empty? then
       result = ""
+    else
+      result += "\n"
     end
     return ("error\n" + result + "Try `help' for protocol information.\n\n")
   end
@@ -92,15 +92,19 @@ class Session < SessionCore
     end
     chunks = line.gsub(/[\r\n]/, "").split("\t")
     if chunks.length > 0 then
-      name = chunks.shift.intern
+      name = chunks.shift
       args = chunks
       return send_command(name, args)
     end
   end
 
   def send_command (name, args)
-    command = @command_table[name]
-    if command.nil?
+    if name.empty? then
+      return reply_unsuccessful("Empty command:")
+    end
+
+    command = @command_table[name.intern]
+    if command.nil? then
       return reply_unsuccessful("Unknown command: #{name}")
     elsif command.min_nargs <= args.length and args.length <= command.nargs
       return send(command.name, *args)
